@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -78,9 +78,9 @@ private:
 	LPMAPISESSION m_lpSession;
 	std::wstring m_strError;
 	convert_context m_converter;
-	vmime::charset m_vmCharset;
-	std::string m_strCharset;
-	std::string m_strHTMLCharset;
+	vmime::charset m_vmCharset;		//!< charset to use in email
+	std::string m_strCharset;		//!< charset to use in email + //TRANSLIT tag
+	std::string m_strHTMLCharset;	//!< HTML body charset in MAPI message (input)
 
 	HRESULT fillVMIMEMail(IMessage *lpMessage, bool bSkipContent, vmime::messageBuilder* lpVMMessageBuilder);
 
