@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -64,11 +64,12 @@ enum BODYLEVEL { BODY_NONE, BODY_PLAIN, BODY_HTML };
 enum ATTACHLEVEL { ATTACH_NONE, ATTACH_INLINE, ATTACH_NORMAL };
 
 typedef struct sMailState {
-	BODYLEVEL bodyLevel;
-	ATTACHLEVEL attachLevel;
-	bool bAttachSignature;
-	ULONG ulMsgInMsg;
-	std::string strHTMLBody;
+	BODYLEVEL bodyLevel;		//!< the current body state. plain upgrades none, html upgrades plain and none.
+	ULONG ulLastCP;
+	ATTACHLEVEL attachLevel;	//!< the current attachment state
+	bool bAttachSignature;		//!< add a signed signature at the end
+	ULONG ulMsgInMsg;			//!< counter for msg-in-msg level
+	std::string strHTMLBody;	//!< cache for the current complete untouched HTML body, used for finding CIDs or locations (inline images)
 
 	sMailState() {
 		this->reset();
@@ -76,6 +77,7 @@ typedef struct sMailState {
 	};
 	void reset() {
 		bodyLevel = BODY_NONE;
+		ulLastCP = 0;
 		attachLevel = ATTACH_NONE;
 		bAttachSignature = false;
 		strHTMLBody.clear();
@@ -101,7 +103,7 @@ private:
 	convert_context m_converter;
 
 	HRESULT fillMAPIMail(vmime::ref<vmime::message> vmMessage, IMessage *lpMessage);
-	HRESULT disectBody(vmime::ref<vmime::header> vmHeader, vmime::ref<vmime::body> vmBody, IMessage* lpMessage, bool onlyBody = false, bool filterDouble = false, bool bAppendBody = false);
+	HRESULT disectBody(vmime::ref<vmime::header> vmHeader, vmime::ref<vmime::body> vmBody, IMessage* lpMessage, bool onlyBody = false, bool filterDouble = false, bool appendBody = false);
 
 	HRESULT handleHeaders(vmime::ref<vmime::header> vmHeader, IMessage* lpMessage);
 	HRESULT handleRecipients(vmime::ref<vmime::header> vmHeader, IMessage* lpMessage);
