@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -117,8 +117,8 @@ public:
 	UCHAR getDayOfMonth();
 	HRESULT setDayOfMonth(UCHAR);
 
-	UCHAR getMonth();			/* 0..11 */
-/* 	HRESULT setMonth(UCHAR); */
+	UCHAR getMonth();
+ 	HRESULT setMonth(UCHAR);
 
 	UCHAR getWeekNumber();		/* 1..4 and 5 (last) */
 	HRESULT setWeekNumber(UCHAR);
@@ -178,11 +178,12 @@ public:
 
 	bool isOccurrence(time_t);
 	bool isRuleOccurrence(time_t);
-*/
-	time_t calcEndDate();
-	ULONG calcCount();
 
 	bool isAfter(time_t);
+*/
+	time_t calcStartDate();
+	time_t calcEndDate();
+	ULONG calcCount();
 
 	static time_t MonthInSeconds(ULONG year, ULONG month);
 	static time_t MonthsInSeconds(ULONG months);
@@ -209,6 +210,7 @@ public:
 
 private:
 	RecurrenceState m_sRecState;
+	unsigned int m_ulMonth;       // yearly, 1...12 (Not stored in the struct)
 
 	std::vector<std::wstring> vExceptionsSubject;
 	std::vector<std::wstring> vExceptionsLocation;
