@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -105,9 +105,10 @@ public:
 
 	// lpParent is public because it is always thread-safe and valid
 	ECUnknown				*lpParent;
+	virtual BOOL IsParentOf(ECUnknown *lpObject);
+	virtual BOOL IsChildOf(ECUnknown *lpObject);
 
 protected:
-
 	// Called by AddChild
 	virtual HRESULT SetParent(ECUnknown *lpParent);
 
