@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -96,7 +96,7 @@
 #define ZARAFA_E_INVALID_BOOKMARK		MAKE_ZARAFA_E( 39 )
 #define ZARAFA_E_UNABLE_TO_COMPLETE		MAKE_ZARAFA_E( 40 )
 #define ZARAFA_E_UNKNOWN_INSTANCE_ID	MAKE_ZARAFA_E( 41 )
-#define ZARAFA_E_IGNORE_ME			MAKE_ZARAFA_E( 42 )
+#define ZARAFA_E_IGNORE_ME				MAKE_ZARAFA_E( 42 )
 #define ZARAFA_E_BUSY					MAKE_ZARAFA_E( 43 )
 #define ZARAFA_E_OBJECT_DELETED			MAKE_ZARAFA_E( 44 )
 #define ZARAFA_E_USER_CANCEL			MAKE_ZARAFA_E( 45 )
@@ -153,7 +153,7 @@ typedef unsigned int ECRESULT;
 #define ATTACH_PATHDEPTH_LEVEL1 10
 #define ATTACH_PATHDEPTH_LEVEL2 20
 
-typedef enum { CONNECTION_TYPE_TCP, CONNECTION_TYPE_SSL, CONNECTION_TYPE_NAMED_PIPE } CONNECTION_TYPE;
+typedef enum { CONNECTION_TYPE_TCP, CONNECTION_TYPE_SSL, CONNECTION_TYPE_NAMED_PIPE, CONNECTION_TYPE_NAMED_PIPE_PRIORITY } CONNECTION_TYPE;
 
 //Functions
 HRESULT ZarafaErrorToMAPIError(ECRESULT ecResult, HRESULT hrDefault = 0x80070005 /*MAPI_E_NO_ACCESS*/);
