@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -59,6 +59,7 @@
 #define dispidOtherAddress					0x801C	//PT_STRING8
 #define dispidSelectedMailingAddress		0x8022	//PT_LONG
 #define dispidJournal						0x8025	//PT_BOOLEAN
+#define dispidABPEmailList					0x8028	//PT_MV_LONG
 #define dispidWebPage						0x802B	//PT_STRING8
 #define dispidWorkAddressStreet				0x8045	//PT_STRING8
 #define dispidWorkAddressCity				0x8046	//PT_STRING8
@@ -164,6 +165,7 @@
 #define dispidApptReplyTime					0x8220	//PT_SYSTIME
 
 #define dispidOrgMsgId						0x8251  //PT_BINARY
+#define dispidZmtVersion					0x8252	//PT_STRING8
 
 // New in OLK 2007
 #define dispidApptTZDefStartDisplay			0x825E
