@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -53,14 +53,17 @@
 
   // We have to include this now in case select.h is included too soon.
   // Increase our maximum amount of file descriptors to 8192
-#if OPENBSD
+  // But only if you don't have a glibc that doesn't check for this compiletime limit
+  #ifndef _FORTIFY_SOURCE
+  #if OPENBSD
   #include <sys/types.h>
   #include <sys/select.h>
-#else
+  #else
   #include <bits/types.h>
-#endif
+  #endif
   #undef __FD_SETSIZE
   #define __FD_SETSIZE 8192
+  #endif
 
   // Log the pthreads locks
   #define DEBUG_PTHREADS 0
