@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -129,6 +129,7 @@ static inline bool parseBool(const std::string &s) {
 
 std::string shell_escape(std::string str);
 std::string shell_escape(std::wstring wstr);
+std::string forcealnum(const std::string& str, const char *additional = NULL);
 
 std::vector<std::wstring> tokenize(const std::wstring &strInput, const WCHAR sep);
 std::vector<std::string> tokenize(const std::string &strInput, const char sep);
@@ -158,6 +159,10 @@ std::string urlDecode(const std::string &input);
 
 std::string StringEscape(const char* input, const char *tokens, const char escape);
 
+void BufferLFtoCRLF(size_t size, const char *input, char *output, size_t *outsize);
+void StringCRLFtoLF(const std::wstring &strInput, std::wstring *lpstrOutput);
+void StringTabtoSpaces(const std::wstring &strInput, std::wstring *lpstrOutput);
+
 template<typename T>
 std::vector<T> tokenize(const T &str, const T &delimiters)
 {
