@@ -1274,6 +1274,22 @@ PR_EMS_AB_ROOM_CAPACITY = PROP_TAG(PT_LONG, 0x0807)
 PR_EMS_AB_ROOM_DESCRIPTION = PROP_TAG(PT_STRING8, 0x0809)
 PR_EMS_AB_HOME_MDB = PROP_TAG(PT_STRING8, 0x8006)
 PR_EMS_AB_HOME_MTA = PROP_TAG(PT_STRING8, 0x8007)
+PR_EMSMDB_SECTION_UID = PROP_TAG(PT_BINARY, 0x3D15)
+
+# Freebusy properties
+PR_FREEBUSY_START_RANGE = PROP_TAG(PT_LONG, 0x6847)
+PR_FREEBUSY_END_RANGE = PROP_TAG(PT_LONG, 0x6848)
+PR_FREEBUSY_EMAIL_ADDRESS = PROP_TAG(PT_TSTRING, 0x6849)
+PR_FREEBUSY_ALL_MONTHS = PROP_TAG(PT_MV_LONG, 0x684F)
+PR_FREEBUSY_ALL_EVENTS = PROP_TAG(PT_MV_BINARY, 0x6850)
+PR_FREEBUSY_TENTATIVE_MONTHS = PROP_TAG(PT_MV_LONG, 0x6851)
+PR_FREEBUSY_TENTATIVE_EVENTS = PROP_TAG(PT_MV_BINARY, 0x6852)
+PR_FREEBUSY_BUSY_MONTHS = PROP_TAG(PT_MV_LONG, 0x6853)
+PR_FREEBUSY_BUSY_EVENTS = PROP_TAG(PT_MV_BINARY, 0x6854)
+PR_FREEBUSY_OOF_MONTHS = PROP_TAG(PT_MV_LONG, 0x6855)
+PR_FREEBUSY_OOF_EVENTS = PROP_TAG(PT_MV_BINARY, 0x6856)
+PR_FREEBUSY_LAST_MODIFIED = PROP_TAG(PT_SYSTIME, 0x6868)
+PR_FREEBUSY_NUM_MONTHS = PROP_TAG(PT_LONG, 0x6869)  
 
 # MAPI IIDs
 IID_IUnknown = DEFINE_OLEGUID(0,0,0)
@@ -1352,7 +1368,17 @@ PR_EC_FLAGS				= PROP_TAG(PT_LONG, PR_EC_BASE + 0x04)
 PR_EC_SSLKEY_FILE		= PROP_TAG(PT_STRING8, PR_EC_BASE + 0x05)
 PR_EC_SSLKEY_PASS		= PROP_TAG(PT_STRING8, PR_EC_BASE + 0x06)
 
-PR_EC_STOREGUID         =  PROP_TAG(PT_BINARY, PR_EC_BASE+0x12)
+PR_EC_HIERARCHYID       	= PROP_TAG(PT_LONG,               PR_EC_BASE+0x11)
+PR_EC_STOREGUID             = PROP_TAG(PT_BINARY,             PR_EC_BASE+0x12)
+PR_EC_COMPANYID             = PROP_TAG(PT_LONG,               PR_EC_BASE+0x13)
+PR_EC_STORETYPE             = PROP_TAG(PT_LONG,               PR_EC_BASE+0x14)
+PR_EC_PARENT_HIERARCHYID    = PROP_TAG(PT_LONG,               PR_EC_BASE+0x15)
+
+PR_ZC_CONTACT_STORE_ENTRYIDS =	PROP_TAG(PT_MV_BINARY,  PR_EC_BASE + 0x11)
+PR_ZC_CONTACT_FOLDER_ENTRYIDS =	PROP_TAG(PT_MV_BINARY,  PR_EC_BASE + 0x12)
+PR_ZC_CONTACT_FOLDER_NAMES =	PROP_TAG(PT_MV_TSTRING, PR_EC_BASE + 0x13)
+PR_ZC_CONTACT_FOLDER_NAMES_A =	PROP_TAG(PT_MV_STRING8, PR_EC_BASE + 0x13)
+PR_ZC_CONTACT_FOLDER_NAMES_W =	PROP_TAG(PT_MV_UNICODE, PR_EC_BASE + 0x13)
 
 PR_EC_CHANGE_ADVISOR	= PROP_TAG(PT_OBJECT, PR_EC_BASE+0x89)
 
@@ -1428,6 +1454,8 @@ PURGE_CACHE_USERDETAILS		= 0x0800
 PURGE_CACHE_SERVER			= 0x1000
 PURGE_CACHE_ALL				= 0xFFFFFFFF
 
+pbGlobalProfileSectionGuid = DEFINE_GUID(0xC8B0DB13, 0x05AA, 0x1A10, 0x9B,0xB0, 0x00, 0xAA, 0x00, 0x2F, 0xC4, 0x5A);
+
 # Exchange IIDs.
 IID_IExchangeManageStore = DEFINE_GUID(0x559d10b0,0xa772,0x11cd,0x9b,0xc8,0x00,0xaa,0x00,0x2f,0xc4,0x5a)
 IID_IExchangeManageStore2 = DEFINE_GUID(0xb6dca470,0xff3,0x11d0,0xa4,0x9,0x0,0xc0,0x4f,0xd7,0xbd,0x87)
@@ -1485,7 +1513,7 @@ LIBID_rulecls = DEFINE_GUID(0xF111A8E6,0x4462,0x11CE,0xA8,0xDE,0x00,0xAA,0x00,0x
 IID_IExchangeFolderRules = DEFINE_GUID(0xF111A8E7,0x4462,0x11CE,0xA8,0xDE,0x00,0xAA,0x00,0x4A,0xC5,0xC1)
 GUID_ExchangeFormExts = DEFINE_GUID(0x77f69534,0x6b7d,0x101b,0x9f,0x0d,0x00,0xaa,0x00,0x3b,0xa9,0x05)
 IID_IOutlookExtCallback = DEFINE_GUID(0x0006720d,0x0000,0x0000,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x46)
-# DEFINE_GUID(_name,(0x29F3AB10 + _l)0x554D,0x11D0,0xA9,\
+IID_IProxyStoreObject = DEFINE_GUID(0x29F3AB10,0x554D,0x11D0,0xA9,0x7C,0x00,0xA0,0xC9,0x11,0xF5,0x0A)
 # DEFINE_GUID(IID_IAttachmentSecurity,
 IID_IFolderSupport = DEFINE_GUID(0x00375ac3,0xecaf,0x4ef8,0xa5,0x27,0x34,0xf4,0x52,0xfa,0x9c,0x67)
 IID_ISelectUnicode = DEFINE_GUID(0x05EB1EB9,0xE334,0x4EB7,0xAC,0x4D,0x0B,0xCE,0xC7,0xC6,0xE0,0xC1)
@@ -1493,6 +1521,7 @@ IID_ISelectUnicode = DEFINE_GUID(0x05EB1EB9,0xE334,0x4EB7,0xAC,0x4D,0x0B,0xCE,0x
 ZARAFA_SERVICE_GUID = DEFINE_GUID(0x3c253dca,0xd227,0x443c,0x94,0xfe,0x42,0x5f,0xab,0x95,0x8c,0x19)
 ZARAFA_STORE_PUBLIC_GUID = DEFINE_GUID(0xd47f4a09,0xd3bd,0x493c,0xb2,0xfc,0x3c,0x90,0xbb,0xcb,0x48,0xd4)
 ZARAFA_STORE_DELEGATE_GUID = DEFINE_GUID(0x7c7c1085,0xbc6d,0x4e53,0x9d,0xab,0x8a,0x53,0xf8,0xde,0xf8,0x8)
+ZARAFA_STORE_ARCHIVE_GUID = DEFINE_GUID(0xbc8953ad,0x2e3f,0x4172,0x94,0x4,0x89,0x6f,0xf4,0x59,0x87,0xf)
 ZARAFA_SAB_GUID = DEFINE_GUID(0x5abae40e,0x1df7,0x4f3d,0x96,0x4d,0x65,0x8a,0x79,0x92,0x4e,0x9d)
 IID_IECSingleInstance = DEFINE_GUID(0xa7d80ed6,0xd027,0x11dd,0xb0,0xb6,0x64,0x50,0x55,0xd8,0x95,0x93)
 IID_IECSpooler = DEFINE_GUID(0x20c5963f,0xe0b,0x4d7f,0xb7,0x5d,0x8a,0xcd,0x88,0x72,0x71,0x19)
